@@ -41,7 +41,7 @@ fi
 
 if [ $database_type == 'mysql' ]; then
     echo "########################### Start MySQL ######################################"
-    /usr/libexec/mysqldtoto --user=root &
+    /usr/sbin/mysqldtoto --user=root &
 else
     echo "########################### Start MariaDB ######################################"
     if [ "$distrib" = "ALMALINUX" ]; then
@@ -67,7 +67,6 @@ fi
 
 
 ulimit -c unlimited
-ulimit -S -n 524288
 
 #only privileged container can write core files
 if [ $test_file != 'connector_ssh/connector_ssh.robot' ] ; then
