@@ -73,6 +73,9 @@
 #include <spdlog/fmt/ostr.h>
 #include <spdlog/spdlog.h>
 
+#include <fmt/format.h>
+#include <fmt/ranges.h>
+
 #include <boost/algorithm/string.hpp>
 #include <boost/exception/diagnostic_information.hpp>
 
