@@ -1,23 +1,22 @@
-/*
-** Copyright 2023 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2023 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/broker/cache/global_cache_data.hh"
-#include "com/centreon/broker/log_v2.hh"
 
 using namespace com::centreon::broker::cache;
 
@@ -63,8 +62,8 @@ void global_cache_data::managed_map(bool create) {
  */
 void global_cache_data::set_metric_info(uint64_t metric_id,
                                         uint64_t index_id,
-                                        const absl::string_view& name,
-                                        const absl::string_view& unit,
+                                        const std::string_view& name,
+                                        const std::string_view& unit,
                                         double min,
                                         double max) {
   try {
@@ -92,7 +91,7 @@ void global_cache_data::set_metric_info(uint64_t metric_id,
       _metric_info->emplace(metric_id, to_add);
     }
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     set_metric_info(metric_id, index_id, name, unit, min, max);
   }
@@ -105,7 +104,7 @@ void global_cache_data::set_metric_info(uint64_t metric_id,
  * @param instance_name
  */
 void global_cache_data::store_instance(uint64_t instance_id,
-                                       const absl::string_view& instance_name) {
+                                       const std::string_view& instance_name) {
   try {
     absl::WriterMutexLock l(&_protect);
     auto exist = _id_to_instance->find(instance_id);
@@ -122,7 +121,7 @@ void global_cache_data::store_instance(uint64_t instance_id,
       exist->second.assign(instance_name.data(), instance_name.length());
     }
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     store_instance(instance_id, instance_name);
   }
@@ -137,7 +136,7 @@ void global_cache_data::store_instance(uint64_t instance_id,
  * @param severity_id
  */
 void global_cache_data::store_host(uint64_t host_id,
-                                   const absl::string_view& host_name,
+                                   const std::string_view& host_name,
                                    uint64_t resource_id,
                                    uint64_t severity_id) {
   try {
@@ -159,7 +158,7 @@ void global_cache_data::store_host(uint64_t host_id,
       exist->second.severity_id = severity_id;
     }
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     store_host(host_id, host_name, resource_id, severity_id);
   }
@@ -177,7 +176,7 @@ void global_cache_data::store_host(uint64_t host_id,
 void global_cache_data::store_service(
     uint64_t host_id,
     uint64_t service_id,
-    const absl::string_view& service_description,
+    const std::string_view& service_description,
     uint64_t resource_id,
     uint64_t severity_id) {
   try {
@@ -203,7 +202,7 @@ void global_cache_data::store_service(
     }
 
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     store_service(host_id, service_id, service_description, resource_id,
                   severity_id);
@@ -228,7 +227,7 @@ void global_cache_data::set_index_mapping(uint64_t index_id,
     }
     _index_id_mapping->emplace(index_id, host_serv_pair(host_id, service_id));
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     set_index_mapping(index_id, host_id, service_id);
   }
@@ -239,15 +238,18 @@ void global_cache_data::set_index_mapping(uint64_t index_id,
  *
  * @param group
  * @param host
+ * @param poller_id
  */
-void global_cache_data::add_host_group(uint64_t group, uint64_t host) {
+void global_cache_data::add_host_to_group(uint64_t group,
+                                          uint64_t host,
+                                          uint64_t poller_id) {
   try {
     absl::WriterMutexLock l(&_protect);
-    _host_group->emplace(host_group_element{host, group});
+    _host_group->emplace(host_group_element{host, group, poller_id});
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
-    add_host_group(group, host);
+    add_host_to_group(group, host, poller_id);
   }
 }
 
@@ -263,13 +265,22 @@ void global_cache_data::remove_host_from_group(uint64_t group, uint64_t host) {
 }
 
 /**
- * @brief remove host group
+ * @brief remove all members of an host group and poller
  *
- * @param group
+ * @param group id of the group
+ * @param poller_id id of the poller
  */
-void global_cache_data::remove_host_group(uint64_t group) {
+void global_cache_data::remove_host_group_members(uint64_t group,
+                                                  uint64_t poller_id) {
   absl::WriterMutexLock l(&_protect);
-  _host_group->get<1>().erase(group);
+  auto range_iters = _host_group->get<1>().equal_range(group);
+  while (range_iters.first != range_iters.second) {
+    if (range_iters.first->poller_id == poller_id) {
+      range_iters.first = _host_group->get<1>().erase(range_iters.first);
+    } else {
+      ++range_iters.first;
+    }
+  }
 }
 
 /**
@@ -278,17 +289,20 @@ void global_cache_data::remove_host_group(uint64_t group) {
  * @param group
  * @param host
  * @param service
+ * @param poller_id
  */
-void global_cache_data::add_service_group(uint64_t group,
-                                          uint64_t host,
-                                          uint64_t service) {
+void global_cache_data::add_service_to_group(uint64_t group,
+                                             uint64_t host,
+                                             uint64_t service,
+                                             uint64_t poller_id) {
   try {
     absl::WriterMutexLock l(&_protect);
-    _service_group->emplace(service_group_element{{host, service}, group});
+    _service_group->emplace(
+        service_group_element{{host, service}, group, poller_id});
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
-    add_service_group(group, host, service);
+    add_service_to_group(group, host, service, poller_id);
   }
 }
 
@@ -307,13 +321,22 @@ void global_cache_data::remove_service_from_group(uint64_t group,
 }
 
 /**
- * @brief remove a service group
+ * @brief remove all members of a service group and a poller
  *
- * @param group
+ * @param group id of a group
+ * @param poller_id id of the poller
  */
-void global_cache_data::remove_service_group(uint64_t group) {
+void global_cache_data::remove_service_group_members(uint64_t group,
+                                                     uint64_t poller_id) {
   absl::WriterMutexLock l(&_protect);
-  _service_group->get<1>().erase(group);
+  auto range_iters = _service_group->get<1>().equal_range(group);
+  while (range_iters.first != range_iters.second) {
+    if (range_iters.first->poller_id == poller_id) {
+      range_iters.first = _service_group->get<1>().erase(range_iters.first);
+    } else {
+      ++range_iters.first;
+    }
+  }
 }
 
 /**
@@ -325,7 +348,7 @@ void global_cache_data::remove_service_group(uint64_t group) {
  * @param poller_id
  */
 void global_cache_data::add_tag(uint64_t tag_id,
-                                const absl::string_view& tag_name,
+                                const std::string_view& tag_name,
                                 TagType tag_type,
                                 uint64_t poller_id) {
   try {
@@ -347,7 +370,7 @@ void global_cache_data::add_tag(uint64_t tag_id,
       }
     }
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     add_tag(tag_id, tag_name, tag_type, poller_id);
   }
@@ -376,11 +399,11 @@ void global_cache_data::set_host_tag(uint64_t host,
   try {
     absl::WriterMutexLock l(&_protect);
     uint64_t tag_id;
-    while (tag_id = tag_filler()) {
+    while ((tag_id = tag_filler())) {
       _host_tag->insert({host, tag_id});
     }
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     set_host_tag(host, std::move(tag_filler));
   }
@@ -398,11 +421,11 @@ void global_cache_data::set_serv_tag(uint64_t host,
   try {
     absl::WriterMutexLock l(&_protect);
     uint64_t tag_id;
-    while (tag_id = tag_filler()) {
+    while ((tag_id = tag_filler())) {
       _serv_tag->insert({{host, serv}, tag_id});
     }
   } catch (const interprocess::bad_alloc& e) {
-    SPDLOG_LOGGER_DEBUG(log_v2::core(), "file full => grow");
+    SPDLOG_LOGGER_DEBUG(_logger, "file full => grow");
     allocation_exception_handler();
     set_serv_tag(host, serv, std::move(tag_filler));
   }
