@@ -20,11 +20,19 @@
 #include <arpa/inet.h>
 #include <gtest/gtest.h>
 
+#include "com/centreon/broker/neb/custom_variable.hh"
+#include "com/centreon/broker/neb/host.hh"
+#include "com/centreon/broker/neb/host_group.hh"
+#include "com/centreon/broker/neb/host_group_member.hh"
+#include "com/centreon/broker/neb/instance.hh"
+#include "com/centreon/broker/neb/service.hh"
+#include "com/centreon/broker/neb/service_group.hh"
+#include "com/centreon/broker/neb/service_group_member.hh"
+
 #include "com/centreon/broker/bbdo/stream.hh"
 #include "com/centreon/broker/config/applier/init.hh"
 #include "com/centreon/broker/config/applier/modules.hh"
 #include "com/centreon/broker/io/raw.hh"
-#include "com/centreon/broker/lua/macro_cache.hh"
 #include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/broker/misc/variant.hh"
 #include "com/centreon/broker/neb/instance.hh"
@@ -96,7 +104,7 @@ class OutputTest : public ::testing::Test {
 // function.
 TEST_F(OutputTest, WriteService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service> svc(std::make_shared<neb::service>());
   svc->host_id = 12345;
@@ -141,7 +149,7 @@ TEST_F(OutputTest, WriteService) {
 
 TEST_F(OutputTest, WriteLongService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   auto svc = std::make_shared<neb::service>();
   svc->host_id = 12;
@@ -189,7 +197,7 @@ TEST_F(OutputTest, WriteLongService) {
 
 TEST_F(OutputTest, WriteReadService) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service> svc(new neb::service);
   svc->host_id = 12345;
@@ -233,7 +241,7 @@ TEST_F(OutputTest, WriteReadService) {
 
 TEST_F(OutputTest, ShortPersistentFile) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service_status> svc(new neb::service_status);
   svc->host_id = 12345;
@@ -278,7 +286,7 @@ TEST_F(OutputTest, ShortPersistentFile) {
 
 TEST_F(OutputTest, LongPersistentFile) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service> svc(new neb::service);
   svc->host_id = 12345;
@@ -322,7 +330,7 @@ TEST_F(OutputTest, LongPersistentFile) {
 
 TEST_F(OutputTest, WriteReadBadChksum) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service> svc(new neb::service);
   svc->host_id = 12345;
@@ -361,7 +369,7 @@ TEST_F(OutputTest, WriteReadBadChksum) {
 
 TEST_F(OutputTest, ServiceTooShort) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service> svc(new neb::service);
   svc->host_id = 12345;
@@ -407,7 +415,7 @@ TEST_F(OutputTest, ServiceTooShort) {
 
 TEST_F(OutputTest, ServiceTooShortAndAGoodOne) {
   config::applier::modules modules(_logger);
-  modules.load_file("./broker/neb/10-neb.so");
+  modules.load_file("./broker/lib/10-neb.so");
 
   std::shared_ptr<neb::service> svc(new neb::service);
   svc->host_id = 12345;
