@@ -104,8 +104,9 @@ const std::string com::centreon::broker::grpc::authorization_header(
  * @tparam bireactor_class
  */
 template <class bireactor_class>
-std::set<std::shared_ptr<stream<bireactor_class>>>
-    stream<bireactor_class>::_instances;
+std::set<std::shared_ptr<stream<bireactor_class>>>*
+    stream<bireactor_class>::_instances =
+        new std::set<std::shared_ptr<stream<bireactor_class>>>;
 
 template <class bireactor_class>
 std::mutex stream<bireactor_class>::_instances_m;
@@ -118,12 +119,16 @@ std::mutex stream<bireactor_class>::_instances_m;
  * @param class_name used by logs to identify server or client case
  */
 template <class bireactor_class>
-stream<bireactor_class>::stream(const grpc_config::pointer& conf,
-                                const std::string_view& class_name)
+stream<bireactor_class>::stream(
+    const grpc_config::pointer& conf,
+    const std::string_view& class_name,
+    const std::shared_ptr<asio::io_context> io_context,
+    const std::shared_ptr<spdlog::logger>& logger)
     : io::stream("GRPC"),
       _conf(conf),
       _class_name(class_name),
-      _logger{log_v2::instance().get(log_v2::GRPC)} {
+      _logger{logger},
+      _io_context(io_context) {
   SPDLOG_LOGGER_DEBUG(_logger, "create {} this={:p}", _class_name,
                       static_cast<const void*>(this));
 }
@@ -149,7 +154,7 @@ template <class bireactor_class>
 void stream<bireactor_class>::register_stream(
     const std::shared_ptr<stream<bireactor_class>>& strm) {
   std::lock_guard l(_instances_m);
-  _instances.insert(strm);
+  _instances->insert(strm);
 }
 
 /**
@@ -230,7 +235,7 @@ bool stream<bireactor_class>::read(std::shared_ptr<io::data>& d,
                           _class_name, *std::static_pointer_cast<io::raw>(d));
       return true;
     } else {
-      d = protobuf_to_event(first);
+      d = protobuf_to_event(first, _logger);
       if (d) {
         SPDLOG_LOGGER_TRACE(_logger, "{:p} {} read:{}",
                             static_cast<void*>(this), _class_name, *d);
@@ -340,7 +345,7 @@ int32_t stream<bireactor_class>::write(std::shared_ptr<io::data> const& d) {
 
   if (_conf->get_grpc_serialized() &&
       std::dynamic_pointer_cast<io::protobuf_base>(d)) {  // no bbdo serialize
-    to_send = create_event_with_data(d);
+    to_send = create_event_with_data(d, _logger);
   } else {
     to_send = std::make_shared<event_with_data>();
     std::shared_ptr<io::raw> raw_src = std::static_pointer_cast<io::raw>(d);
@@ -363,21 +368,19 @@ int32_t stream<bireactor_class>::write(std::shared_ptr<io::data> const& d) {
 template <class bireactor_class>
 void stream<bireactor_class>::OnDone() {
   stop();
-
   /**grpc has a bug, sometimes if we delete this class in this handler as it is
    * described in examples, it also deletes used channel and does a pthread_join
    * of the current thread which go to a EDEADLOCK error and call grpc::Crash.
    * So we uses asio thread to do the job
    */
-  common::pool::io_context().post(
-      [me = std::enable_shared_from_this<
-           stream<bireactor_class>>::shared_from_this(),
-       logger = _logger]() {
-        std::lock_guard l(_instances_m);
-        SPDLOG_LOGGER_DEBUG(logger, "{:p} server::OnDone()",
-                            static_cast<void*>(me.get()));
-        _instances.erase(std::static_pointer_cast<stream<bireactor_class>>(me));
-      });
+  asio::post(*_io_context, [me = std::enable_shared_from_this<
+                                stream<bireactor_class>>::shared_from_this(),
+                            logger = _logger]() {
+    std::lock_guard l(_instances_m);
+    SPDLOG_LOGGER_DEBUG(logger, "{:p} server::OnDone()",
+                        static_cast<void*>(me.get()));
+    _instances->erase(std::static_pointer_cast<stream<bireactor_class>>(me));
+  });
 }
 
 /**
@@ -390,22 +393,20 @@ void stream<bireactor_class>::OnDone() {
 template <class bireactor_class>
 void stream<bireactor_class>::OnDone(const ::grpc::Status& status) {
   stop();
-
   /**grpc has a bug, sometimes if we delete this class in this handler as it is
    * described in examples, it also deletes used channel and does a
    * pthread_join of the current thread which go to a EDEADLOCK error and call
    * grpc::Crash. So we uses asio thread to do the job
    */
-  common::pool::io_context().post(
-      [me = std::enable_shared_from_this<
-           stream<bireactor_class>>::shared_from_this(),
-       status, logger = _logger]() {
-        std::lock_guard l(_instances_m);
-        SPDLOG_LOGGER_DEBUG(logger, "{:p} client::OnDone({}) {}",
-                            static_cast<void*>(me.get()),
-                            status.error_message(), status.error_details());
-        _instances.erase(std::static_pointer_cast<stream<bireactor_class>>(me));
-      });
+  asio::post(*_io_context, [me = std::enable_shared_from_this<
+                                stream<bireactor_class>>::shared_from_this(),
+                            status, logger = _logger]() {
+    std::lock_guard l(_instances_m);
+    SPDLOG_LOGGER_DEBUG(logger, "{:p} client::OnDone({}) {}",
+                        static_cast<void*>(me.get()), status.error_message(),
+                        status.error_details());
+    _instances->erase(std::static_pointer_cast<stream<bireactor_class>>(me));
+  });
 }
 
 /**
