@@ -1,29 +1,30 @@
 /**
-* Copyright 2012-2013 Centreon
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*     http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*
-* For more information : contact@centreon.com
-*/
+ * Copyright 2012-2013 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/io/file_entry.hh"
 #include <libgen.h>
 #include <cerrno>
 #include <cstdlib>
 #include <cstring>
-#include "com/centreon/exceptions/basic.hh"
+#include "com/centreon/exceptions/msg_fmt.hh"
 
 using namespace com::centreon::io;
+using com::centreon::exceptions::msg_fmt;
 
 /**
  *  Constructor.
@@ -188,7 +189,7 @@ void file_entry::refresh() {
     memset(&_sbuf, 0, sizeof(_sbuf));
   else if (stat(_path.c_str(), &_sbuf)) {
     char const* msg(strerror(errno));
-    throw(basic_error() << "get file information failed: " << msg);
+    throw msg_fmt("get file information failed: {}", msg);
   }
 }
 
