@@ -1,26 +1,26 @@
 /**
-* Copyright 2011-2013 Centreon
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*     http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*
-* For more information : contact@centreon.com
-*/
+ * Copyright 2011-2013 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/connector/log.hh"
 #include "com/centreon/connector/ssh/options.hh"
 #include "com/centreon/connector/ssh/policy.hh"
 #include "com/centreon/connector/ssh/sessions/session.hh"
-#include "com/centreon/exceptions/basic.hh"
+#include "com/centreon/exceptions/msg_fmt.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::connector;
@@ -46,7 +46,7 @@ int main(int argc, char* argv[]) {
     std::string test_file_path;
     try {
       opts.parse(argc - 1, argv + 1);
-    } catch (exceptions::basic const& e) {
+    } catch (exceptions::msg_fmt const& e) {
       std::cout << e.what() << std::endl << opts.usage() << std::endl;
       return EXIT_FAILURE;
     }
@@ -77,13 +77,12 @@ int main(int argc, char* argv[]) {
       // Initialize libssh2.
       log::core()->debug("initializing libssh2");
       if (libssh2_init(0))
-        throw basic_error() << "libssh2 initialization failed";
+        throw exceptions::msg_fmt("libssh2 initialization failed");
       {
         char const* version(libssh2_version(LIBSSH2_VERSION_NUM));
         if (!version)
-          throw basic_error()
-              << "libssh2 version is too old (>= " << LIBSSH2_VERSION
-              << " required)";
+          throw exceptions::msg_fmt(
+              "libssh2 version is too old (>= " LIBSSH2_VERSION " required)");
         log::core()->info("libssh2 version {} successfully loaded", version);
       }
 
