@@ -963,8 +963,8 @@ int anomalydetection::handle_async_check_result(
   std::string plugin_output;
   std::string long_plugin_output;
   std::string perf_data;
-  parse_check_output(output, plugin_output, long_plugin_output, perf_data, true,
-                     false);
+  common::parse_check_output(output, plugin_output, long_plugin_output,
+                             perf_data, true, false);
 
   perf_data = string::extract_perfdata(perf_data, _metric_name);
 
