@@ -39,10 +39,12 @@ using namespace com::centreon::engine::commands;
 raw_v2::raw_v2(const std::shared_ptr<asio::io_context> io_context,
                std::string const& name,
                std::string const& command_line,
-               command_listener* listener)
+               const std::shared_ptr<command_listener>& listener)
     : command(name, command_line, listener, e_type::raw),
       _io_context(io_context),
       _commands_logger(commands_logger) {
+  SPDLOG_LOGGER_TRACE(commands_logger, "create raw_v2 {:p}",
+                      static_cast<const void*>(this));
   if (_command_line.empty()) {
     throw exceptions::msg_fmt(
         "Could not create {}'' command: command line is empty", _name);
@@ -54,6 +56,8 @@ raw_v2::raw_v2(const std::shared_ptr<asio::io_context> io_context,
  *
  */
 raw_v2::~raw_v2() {
+  SPDLOG_LOGGER_TRACE(commands_logger, "delete raw_v2 {:p}",
+                      static_cast<const void*>(this));
   for (std::shared_ptr<com::centreon::common::process<true>> to_kill :
        _running) {
     _commands_logger->debug("raw_v2::~raw_v2: killing process for command '{}'",
@@ -335,8 +339,9 @@ uint64_t raw_v2::run(const std::string& processed_cmd,
     // exit called by pool thread
     new_process->start_process(
         [me = weak_from_this(), command_id, start = time(nullptr)](
-            const common::process<true>& proc, int exit_code, int exit_status,
-            const std::string& std_out, const std::string& std_err) {
+            const common::process<true>& proc, int exit_code,
+            common::e_exit_status exit_status, const std::string& std_out,
+            const std::string& std_err) {
           std::shared_ptr<raw_v2> parent =
               std::static_pointer_cast<raw_v2>(me.lock());
           if (parent) {
@@ -380,7 +385,7 @@ void raw_v2::_on_complete(const common::process<true>& proc,
                           uint64_t command_id,
                           time_t start,
                           int exit_code,
-                          int exit_status,
+                          common::e_exit_status exit_status,
                           const std::string& std_out,
                           const std::string& std_err) {
   SPDLOG_LOGGER_TRACE(_commands_logger, "raw_v2::_on_complete: {} id={}",
@@ -398,13 +403,13 @@ void raw_v2::_on_complete(const common::process<true>& proc,
   res.end_time = time(nullptr);
   res.exit_code = exit_code;
   res.output = !std_out.empty() ? std_out : std_err;
-  res.exit_status = static_cast<process::status>(exit_status);
+  res.exit_status = exit_status;
 
-  if (res.exit_status == process::timeout) {
+  if (res.exit_status == common::e_exit_status::timeout) {
     res.exit_code = service::state_unknown;
     res.output = "(Process Timeout)";
-  } else if ((res.exit_status == process::crash) || (res.exit_code < -1) ||
-             (res.exit_code > 3))
+  } else if ((res.exit_status == common::e_exit_status::crash) ||
+             (res.exit_code < -1) || (res.exit_code > 3))
     res.exit_code = service::state_unknown;
 
   SPDLOG_LOGGER_TRACE(_commands_logger, "raw::finished: name:{} id={}, {}",
@@ -463,14 +468,14 @@ void raw_v2::run(const std::string& processed_cmd,
     new_process->start_process(
         [me = shared_from_this(), command_id, start = time(nullptr), &waiter,
          &done, &res](const common::process<true>&, int exit_code,
-                      int exit_status, const std::string& std_out,
-                      const std::string& std_err) {
+                      common::e_exit_status exit_status,
+                      const std::string& std_out, const std::string& std_err) {
           absl::MutexLock lck(&waiter);
           res.command_id = command_id;
           res.start_time = start;
           res.end_time = time(nullptr);
           res.exit_code = exit_code;
-          res.exit_status = static_cast<process::status>(exit_status);
+          res.exit_status = exit_status;
           res.output = !std_out.empty() ? std_out : std_err;
           done = true;
         },
@@ -488,11 +493,11 @@ void raw_v2::run(const std::string& processed_cmd,
   absl::MutexLock lck(&waiter);
   waiter.Await(absl::Condition(&done));
 
-  if (res.exit_status == process::timeout) {
+  if (res.exit_status == common::e_exit_status::timeout) {
     res.exit_code = service::state_unknown;
     res.output = "(Process Timeout)";
-  } else if (res.exit_status == process::crash || res.exit_code < -1 ||
-             res.exit_code > 3)
+  } else if (res.exit_status == common::e_exit_status::crash ||
+             res.exit_code < -1 || res.exit_code > 3)
     res.exit_code = service::state_unknown;
 
   SPDLOG_LOGGER_TRACE(_commands_logger,
