@@ -21,10 +21,12 @@
 #include "com/centreon/engine/config.hh"
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
-#include "com/centreon/engine/configuration/parser.hh"
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/string.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/parser.hh"
+#endif
 
 using namespace com::centreon::engine;
 using namespace com::centreon::engine::configuration::applier;
@@ -61,19 +63,17 @@ static int dfs_host_path(host* root) {
   dfs_set_status(root, DFS_TEMP_CHECKED);
 
   /* We are scanning the children */
-  for (host_map_unsafe::iterator it(root->child_hosts.begin()),
-       end(root->child_hosts.end());
-       it != end; it++) {
-    int child_status = dfs_get_status(it->second);
+  for (const auto& [_, ptr_host] : root->child_hosts) {
+    int child_status = dfs_get_status(ptr_host);
 
     /* If a child is not checked, check it */
     if (child_status == DFS_UNCHECKED)
-      child_status = dfs_host_path(it->second);
+      child_status = dfs_host_path(ptr_host);
 
     /* If a child already temporary checked, its a problem,
      * loop inside, and its a acked status */
     if (child_status == DFS_TEMP_CHECKED) {
-      dfs_set_status(it->second, DFS_LOOPY);
+      dfs_set_status(ptr_host, DFS_LOOPY);
       dfs_set_status(root, DFS_LOOPY);
     }
 
@@ -84,7 +84,7 @@ static int dfs_host_path(host* root) {
         dfs_set_status(root, DFS_NEAR_LOOP);
 
       /* we already saw this child, it's a problem */
-      dfs_set_status(it->second, DFS_LOOPY);
+      dfs_set_status(ptr_host, DFS_LOOPY);
     }
   }
 
@@ -99,10 +99,10 @@ static int dfs_host_path(host* root) {
 }
 
 /* check for circular paths and dependencies */
-int pre_flight_circular_check(int* w, int* e) {
-  int found(false);
-  int warnings(0);
-  int errors(0);
+int pre_flight_circular_check(uint32_t* w, uint32_t* e) {
+  int found = false;
+  uint32_t warnings = 0;
+  uint32_t errors = 0;
 
   /* bail out if we aren't supposed to verify circular paths */
   if (!verify_circular_paths)
