@@ -862,8 +862,13 @@ void applier::service::remove_object(configuration::service const& obj) {
                                                   obj.service_id());
 
     // remove service from servicegroup->members
-    for (auto& it_s : it->second->get_parent_groups())
+    for (auto& it_s : svc->get_parent_groups()) {
+      // before erasing the service from the servicegroup members, we notify the
+      // broker to delete the member first
+
+      broker_group_member(NEBTYPE_SERVICEGROUPMEMBER_DELETE, svc.get(), it_s);
       it_s->members.erase({host_name, service_description});
+    }
 
     // Notify event broker.
     broker_adaptive_service_data(NEBTYPE_SERVICE_DELETE, NEBFLAG_NONE,
@@ -923,8 +928,13 @@ void applier::service::remove_object(ssize_t idx) {
                                                   obj.service_id());
 
     // remove service from servicegroup->members
-    for (auto& it_s : svc->get_parent_groups())
+    for (auto& it_s : svc->get_parent_groups()) {
+      // before erasing the service from the servicegroup members, we notify the
+      // broker to delete the member first
+
+      broker_group_member(NEBTYPE_SERVICEGROUPMEMBER_DELETE, svc.get(), it_s);
       it_s->members.erase({host_name, service_description});
+    }
 
     // Notify event broker.
     broker_adaptive_service_data(NEBTYPE_SERVICE_DELETE, NEBFLAG_NONE,
