@@ -73,6 +73,16 @@ std::vector<std::string> const& contact::get_addresses() const {
   return _addresses;
 }
 
+/**
+ *  Set addresses.
+ *
+ *  @param[in] addresses  New addresses.
+ */
+void contact::set_addresses(std::vector<std::string>&& addresses) {
+  _addresses = std::move(addresses);
+}
+
+#ifdef LEGACY_CONF
 /**
  *  Set addresses.
  *
@@ -81,6 +91,7 @@ std::vector<std::string> const& contact::get_addresses() const {
 void contact::set_addresses(std::vector<std::string> const& addresses) {
   _addresses = addresses;
 }
+#endif
 
 /**
  *  Return the contact alias
@@ -510,7 +521,7 @@ std::shared_ptr<contact> add_contact(
     std::string const& alias,
     std::string const& email,
     std::string const& pager,
-    std::array<std::string, MAX_CONTACT_ADDRESSES> const& addresses,
+    std::vector<std::string>&& addresses,
     std::string const& svc_notification_period,
     std::string const& host_notification_period,
     int notify_service_ok,
@@ -537,8 +548,7 @@ std::shared_ptr<contact> add_contact(
   }
 
   // Check if the contact already exist.
-  std::string const& id(name);
-  if (contact::contacts.count(id)) {
+  if (contact::contacts.count(name)) {
     engine_logger(log_config_error, basic)
         << "Error: Contact '" << name << "' has already been defined";
     config_logger->error("Error: Contact '{}' has already been defined", name);
@@ -556,12 +566,8 @@ std::shared_ptr<contact> add_contact(
     obj->set_host_notification_period(host_notification_period);
     obj->set_pager(pager);
     obj->set_service_notification_period(svc_notification_period);
-    std::vector<std::string> addr;
-    addr.resize(MAX_CONTACT_ADDRESSES);
 
-    for (unsigned int x(0); x < MAX_CONTACT_ADDRESSES; ++x)
-      addr[x] = addresses[x];
-    obj->set_addresses(addr);
+    obj->set_addresses(std::move(addresses));
 
     // Set remaining contact properties.
     obj->set_can_submit_commands(can_submit_commands > 0);
@@ -840,7 +846,8 @@ bool contact::should_be_notified(notifier::notification_category cat,
                                  notifier::reason_type type,
                                  notifier const& notif) const {
   engine_logger(dbg_functions, basic) << "contact::should_be_notified()";
-  functions_logger->trace("contact::should_be_notified()");
+  functions_logger->trace("contact::should_be_notified() for contact '{}'",
+                          get_name());
   /* Are notifications enabled? */
   switch (notif.get_notifier_type()) {
     case notifier::service_notification: {
@@ -1043,8 +1050,9 @@ bool contact::_to_notify_custom(notifier::reason_type type
   return true;
 }
 
-void contact::resolve(int& w, int& e) {
-  int warnings{0}, errors{0};
+void contact::resolve(uint32_t& w, uint32_t& e) {
+  uint32_t warnings = 0;
+  uint32_t errors = 0;
 
   /* check service notification commands */
   if (get_service_notification_commands().empty()) {
