@@ -40,15 +40,24 @@ void enable_flap_detection_routines() {
   functions_logger->trace("enable_flap_detection_routines()");
 
   /* bail out if we're already set */
+#ifdef LEGACY_CONF
   if (config->enable_flap_detection())
     return;
+#else
+  if (pb_config.enable_flap_detection())
+    return;
+#endif
 
   /* set the attribute modified flag */
   modified_host_process_attributes |= attr;
   modified_service_process_attributes |= attr;
 
   /* set flap detection flag */
+#ifdef LEGACY_CONF
   config->enable_flap_detection(true);
+#else
+  pb_config.set_enable_flap_detection(true);
+#endif
 
   /* send data to event broker */
   broker_adaptive_program_data(NEBTYPE_ADAPTIVEPROGRAM_UPDATE, NEBFLAG_NONE,
@@ -78,15 +87,24 @@ void disable_flap_detection_routines() {
   functions_logger->trace("disable_flap_detection_routines()");
 
   /* bail out if we're already set */
+#ifdef LEGACY_CONF
   if (!config->enable_flap_detection())
     return;
+#else
+  if (!pb_config.enable_flap_detection())
+    return;
+#endif
 
   /* set the attribute modified flag */
   modified_host_process_attributes |= attr;
   modified_service_process_attributes |= attr;
 
   /* set flap detection flag */
+#ifdef LEGACY_CONF
   config->enable_flap_detection(false);
+#else
+  pb_config.set_enable_flap_detection(false);
+#endif
 
   /* send data to event broker */
   broker_adaptive_program_data(NEBTYPE_ADAPTIVEPROGRAM_UPDATE, NEBFLAG_NONE,
