@@ -210,8 +210,7 @@ int notification::execute(
 
   engine_logger(dbg_notifications, basic)
       << contacts_notified << " contacts were notified.";
-  notifications_logger->trace("{} contacts were notified.",
-                              contacts_notified);
+  notifications_logger->trace("{} contacts were notified.", contacts_notified);
   return OK;
 }
 
