@@ -1,20 +1,20 @@
 /**
- * Copyright 2011-2019 Centreon
+ * Copyright 2011-2024 Centreon
  *
- * This file is part of Centreon Engine.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Centreon Engine is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Centreon Engine is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
  *
- * You should have received a copy of the GNU General Public License
- * along with Centreon Engine. If not, see
- * <http://www.gnu.org/licenses/>.
  */
 
 #include "com/centreon/engine/broker.hh"
@@ -242,7 +242,12 @@ bool notifier::_is_notification_viable_normal(reason_type type
   }
 
   /* are notifications enabled? */
-  if (!config->enable_notifications()) {
+#ifdef LEGACY_CONF
+  bool enable_notifications = config->enable_notifications();
+#else
+  bool enable_notifications = pb_config.enable_notifications();
+#endif
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
            "not be sent out.";
@@ -353,19 +358,24 @@ bool notifier::_is_notification_viable_normal(reason_type type
     return false;
   }
 
+#ifdef LEGACY_CONF
+  uint32_t interval_length = config->interval_length();
+#else
+  uint32_t interval_length = pb_config.interval_length();
+#endif
   if (_first_notification_delay > 0 && !_notification[cat_normal] &&
       get_last_hard_state_change() +
-              _first_notification_delay * config->interval_length() >
+              _first_notification_delay * interval_length >
           now) {
     engine_logger(dbg_notifications, more)
         << "This notifier is configured with a first notification delay, we "
            "won't send notification until timestamp "
-        << (_first_notification_delay * config->interval_length());
+        << (_first_notification_delay * interval_length);
     SPDLOG_LOGGER_DEBUG(
         notifications_logger,
         "This notifier is configured with a first notification delay, we "
         "won't send notification until timestamp {}",
-        _first_notification_delay * config->interval_length());
+        _first_notification_delay * interval_length);
     return false;
   }
 
@@ -397,19 +407,17 @@ bool notifier::_is_notification_viable_normal(reason_type type
             _last_notification);
         return false;
       } else if (notification_interval > 0) {
-        if (_last_notification +
-                notification_interval * config->interval_length() >
+        if (_last_notification + notification_interval * interval_length >
             now) {
           engine_logger(dbg_notifications, more)
               << "This notifier problem has been sent at " << _last_notification
               << " so it won't be sent until "
-              << (notification_interval * config->interval_length());
+              << (notification_interval * interval_length);
           SPDLOG_LOGGER_DEBUG(
               notifications_logger,
               "This notifier problem has been sent at {} so it won't be sent "
               "until {}",
-              _last_notification,
-              notification_interval * config->interval_length());
+              _last_notification, notification_interval * interval_length);
           return false;
         }
       }
@@ -429,8 +437,13 @@ bool notifier::_is_notification_viable_recovery(reason_type type
   bool retval{true};
   bool send_later{false};
 
+#ifdef LEGACY_CONF
+  bool enable_notifications = config->enable_notifications();
+#else
+  bool enable_notifications = pb_config.enable_notifications();
+#endif
   /* are notifications enabled? */
-  if (!config->enable_notifications()) {
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
            "not be sent out.";
@@ -454,10 +467,20 @@ bool notifier::_is_notification_viable_recovery(reason_type type
     std::time_t now;
     std::time(&now);
 
+#ifdef LEGACY_CONF
+    uint32_t interval_length = config->interval_length();
+    bool use_send_recovery_notifications_anyways =
+        config->use_send_recovery_notifications_anyways();
+#else
+    uint32_t interval_length = pb_config.interval_length();
+    bool use_send_recovery_notifications_anyways =
+        pb_config.send_recovery_notifications_anyways();
+#endif
+
     // if use_send_recovery_notifications_anyways flag is set, we don't take
     // timeperiod into account for recovery
     if (!check_time_against_period_for_notif(now, tp)) {
-      if (config->use_send_recovery_notifications_anyways()) {
+      if (use_send_recovery_notifications_anyways) {
         SPDLOG_LOGGER_DEBUG(notifications_logger,
                             "send_recovery_notifications_anyways flag enabled, "
                             "recovery notification is viable even if we are "
@@ -521,7 +544,7 @@ bool notifier::_is_notification_viable_recovery(reason_type type
       retval = false;
       send_later = false;
     } else if (get_last_hard_state_change() +
-                   _recovery_notification_delay * config->interval_length() >
+                   _recovery_notification_delay * interval_length >
                now) {
       engine_logger(dbg_notifications, more)
           << "This notifier is configured with a recovery notification delay. "
@@ -589,8 +612,13 @@ bool notifier::_is_notification_viable_acknowledgement(
     return true;
   }
 
+#ifdef LEGACY_CONF
+  bool enable_notifications = config->enable_notifications();
+#else
+  bool enable_notifications = pb_config.enable_notifications();
+#endif
   /* are notifications enabled? */
-  if (!config->enable_notifications()) {
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
            "not be sent out.";
@@ -639,7 +667,12 @@ bool notifier::_is_notification_viable_flapping(reason_type type,
   }
 
   /* are notifications enabled? */
-  if (!config->enable_notifications()) {
+#ifdef LEGACY_CONF
+  bool enable_notifications = config->enable_notifications();
+#else
+  bool enable_notifications = pb_config.enable_notifications();
+#endif
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
            "not be sent out.";
@@ -750,7 +783,12 @@ bool notifier::_is_notification_viable_downtime(reason_type type
   }
 
   /* are notifications enabled? */
-  if (!config->enable_notifications()) {
+#ifdef LEGACY_CONF
+  bool enable_notifications = config->enable_notifications();
+#else
+  bool enable_notifications = pb_config.enable_notifications();
+#endif
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
            "not be sent out.";
@@ -771,7 +809,7 @@ bool notifier::_is_notification_viable_downtime(reason_type type
     return false;
   }
 
-  if (!config->enable_notifications()) {
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications won't be sent out.";
     SPDLOG_LOGGER_DEBUG(
@@ -822,7 +860,12 @@ bool notifier::_is_notification_viable_custom(reason_type type
   }
 
   /* are notifications enabled? */
-  if (!config->enable_notifications()) {
+#ifdef LEGACY_CONF
+  bool enable_notifications = config->enable_notifications();
+#else
+  bool enable_notifications = pb_config.enable_notifications();
+#endif
+  if (!enable_notifications) {
     engine_logger(dbg_notifications, more)
         << "Notifications are disabled, so notifications will "
            "not be sent out.";
@@ -1365,8 +1408,8 @@ bool is_contact_for_notifier(com::centreon::engine::notifier* notif,
  * @param e Errors given by the method. An exception is thrown is at less an
  * error is rised.
  */
-void notifier::resolve(int& w, int& e) {
-  int warnings{0}, errors{0};
+void notifier::resolve(uint32_t& w, uint32_t& e) {
+  uint32_t warnings = 0, errors = 0;
 
   /* This list will be filled in {hostescalation,serviceescalation}::resolve */
   _escalations.clear();
@@ -1641,9 +1684,13 @@ time_t notifier::get_next_notification_time(time_t offset) {
                      interval_to_use);
 
   /* calculate next notification time */
+#ifdef LEGACY_CONF
+  uint32_t interval_length = config->interval_length();
+#else
+  uint32_t interval_length = pb_config.interval_length();
+#endif
   time_t next_notification{
-      offset +
-      static_cast<time_t>(interval_to_use * config->interval_length())};
+      offset + static_cast<time_t>(interval_to_use * interval_length)};
 
   return next_notification;
 }
