@@ -35,10 +35,12 @@
 #include "com/centreon/engine/configuration/applier/service.hh"
 #include "com/centreon/engine/configuration/applier/servicedependency.hh"
 #include "com/centreon/engine/configuration/applier/serviceescalation.hh"
-#include "com/centreon/engine/configuration/host.hh"
-#include "com/centreon/engine/configuration/service.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/serviceescalation.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/host.hh"
+#include "common/engine_legacy_conf/service.hh"
+#endif
 #include "helper.hh"
 
 using namespace com::centreon;
@@ -50,28 +52,45 @@ class ServiceNotification : public TestEngine {
  public:
   void SetUp() override {
     init_config_state();
+    error_cnt err;
 
     configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
     configuration::contact ctct{new_configuration_contact("admin", true)};
-    ct_aply.add_object(ctct);
     configuration::contact ctct1{
         new_configuration_contact("admin1", false, "c,r")};
+#else
+    configuration::Contact ctct{new_pb_configuration_contact("admin", true)};
+    configuration::Contact ctct1{
+        new_pb_configuration_contact("admin1", false, "c,r")};
+#endif
+    ct_aply.add_object(ctct);
     ct_aply.add_object(ctct1);
+#ifdef LEGACY_CONF
     ct_aply.expand_objects(*config);
-    ct_aply.resolve_object(ctct);
-    ct_aply.resolve_object(ctct1);
+#else
+    ct_aply.expand_objects(pb_config);
+#endif
+    ct_aply.resolve_object(ctct, err);
+    ct_aply.resolve_object(ctct1, err);
 
+#ifdef LEGACY_CONF
     configuration::host hst{new_configuration_host("test_host", "admin")};
+    configuration::service svc{
+        new_configuration_service("test_host", "test_svc", "admin,admin1")};
+#else
+    configuration::Host hst{new_pb_configuration_host("test_host", "admin")};
+    configuration::Service svc{
+        new_pb_configuration_service("test_host", "test_svc", "admin,admin1")};
+#endif
     configuration::applier::host hst_aply;
     hst_aply.add_object(hst);
 
-    configuration::service svc{
-        new_configuration_service("test_host", "test_svc", "admin,admin1")};
     configuration::applier::service svc_aply;
     svc_aply.add_object(svc);
 
-    hst_aply.resolve_object(hst);
-    svc_aply.resolve_object(svc);
+    hst_aply.resolve_object(hst, err);
+    svc_aply.resolve_object(svc, err);
 
     host_map const& hm{engine::host::hosts};
     _host = hm.begin()->second;
@@ -106,13 +125,11 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotification) {
   ASSERT_EQ(_host->services.size(), 1u);
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
   _svc->set_current_state(engine::service::state_critical);
   _svc->set_last_state(engine::service::state_critical);
   _svc->set_last_hard_state_change(43200);
@@ -132,16 +149,18 @@ TEST_F(ServiceNotification,
   /* We are using a local time() function defined in tests/timeperiod/utils.cc.
    * If we call time(), it is not the glibc time() function that will be called.
    */
+#ifdef LEGACY_CONF
   config->enable_notifications(false);
+#else
+  pb_config.set_enable_notifications(false);
+#endif
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
 
   ASSERT_TRUE(service_escalation);
   uint64_t id{_svc->get_next_notification_id()};
@@ -159,13 +178,11 @@ TEST_F(ServiceNotification,
    */
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
 
   ASSERT_TRUE(service_escalation);
   uint64_t id{_svc->get_next_notification_id()};
@@ -179,7 +196,7 @@ TEST_F(ServiceNotification,
 
 TEST_F(ServiceNotification, SimpleNormalServiceNotificationOutsideTimeperiod) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
@@ -188,7 +205,7 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationOutsideTimeperiod) {
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
@@ -200,9 +217,13 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationOutsideTimeperiod) {
 
 TEST_F(ServiceNotification,
        SimpleNormalServiceNotificationForcedWithNotificationDisabled) {
+#ifdef LEGACY_CONF
   config->enable_notifications(false);
+#else
+  pb_config.set_enable_notifications(false);
+#endif
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
@@ -211,7 +232,7 @@ TEST_F(ServiceNotification,
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
@@ -223,7 +244,7 @@ TEST_F(ServiceNotification,
 
 TEST_F(ServiceNotification, SimpleNormalServiceNotificationForcedNotification) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
@@ -232,7 +253,7 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationForcedNotification) {
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
@@ -244,17 +265,15 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationForcedNotification) {
 
 TEST_F(ServiceNotification, SimpleNormalServiceNotificationWithDowntime) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _svc->set_scheduled_downtime_depth(30);
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
@@ -266,17 +285,15 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationWithDowntime) {
 
 TEST_F(ServiceNotification, SimpleNormalServiceNotificationWithFlapping) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _svc->set_is_flapping(true);
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
@@ -288,17 +305,15 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationWithFlapping) {
 
 TEST_F(ServiceNotification, SimpleNormalServiceNotificationWithSoftState) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _svc->set_state_type(checkable::soft);
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
@@ -311,16 +326,14 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationWithSoftState) {
 TEST_F(ServiceNotification,
        SimpleNormalServiceNotificationWithHardStateAcknowledged) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   _svc->set_acknowledgement(AckType::NORMAL);
@@ -334,16 +347,14 @@ TEST_F(ServiceNotification,
 TEST_F(ServiceNotification,
        SimpleNormalServiceNotificationAfterPreviousTooSoon) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   _svc->set_acknowledgement(AckType::NORMAL);
@@ -358,16 +369,14 @@ TEST_F(ServiceNotification,
 TEST_F(ServiceNotification,
        SimpleNormalServiceNotificationAfterPreviousWithNullInterval) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   _svc->set_acknowledgement(AckType::NORMAL);
@@ -383,16 +392,14 @@ TEST_F(ServiceNotification,
 
 TEST_F(ServiceNotification, SimpleNormalServiceNotificationOnStateNotNotified) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   _svc->set_acknowledgement(AckType::NONE);
@@ -408,16 +415,14 @@ TEST_F(ServiceNotification, SimpleNormalServiceNotificationOnStateNotNotified) {
 TEST_F(ServiceNotification,
        SimpleNormalServiceNotificationOnStateBeforeFirstNotifDelay) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   _svc->set_acknowledgement(AckType::NONE);
@@ -435,16 +440,14 @@ TEST_F(ServiceNotification,
 TEST_F(ServiceNotification,
        SimpleNormalServiceNotificationOnStateAfterFirstNotifDelay) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   _svc->set_acknowledgement(AckType::NONE);
@@ -465,13 +468,11 @@ TEST_F(ServiceNotification,
    */
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (uint32_t i = 0; i < tperiod->days.size(); ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
 
   _svc->set_current_state(engine::service::state_critical);
   _svc->set_last_state(engine::service::state_critical);
@@ -756,24 +757,51 @@ TEST_F(ServiceNotification, NormalRecoveryTwoTimes) {
 TEST_F(ServiceNotification, ServiceEscalationCG) {
   init_macros();
   configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
   configuration::contact ctct{new_configuration_contact("test_contact", false)};
+#else
+  configuration::Contact ctct{
+      new_pb_configuration_contact("test_contact", false)};
+#endif
   ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
   ct_aply.expand_objects(*config);
-  ct_aply.resolve_object(ctct);
+#else
+  ct_aply.expand_objects(pb_config);
+#endif
+  error_cnt err;
+  ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
+#ifdef LEGACY_CONF
   configuration::contactgroup cg{
       new_configuration_contactgroup("test_cg", "test_contact")};
+#else
+  configuration::Contactgroup cg;
+  configuration::contactgroup_helper cg_hlp(&cg);
+  fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
+#endif
   cg_aply.add_object(cg);
+#ifdef LEGACY_CONF
   cg_aply.expand_objects(*config);
-  cg_aply.resolve_object(cg);
+#else
+  cg_aply.expand_objects(pb_config);
+#endif
+  cg_aply.resolve_object(cg, err);
 
   configuration::applier::serviceescalation se_aply;
+#ifdef LEGACY_CONF
   configuration::serviceescalation se{
       new_configuration_serviceescalation("test_host", "test_svc", "test_cg")};
   se_aply.add_object(se);
   se_aply.expand_objects(*config);
-  se_aply.resolve_object(se);
+#else
+  configuration::Serviceescalation se{new_pb_configuration_serviceescalation(
+      "test_host", "test_svc", "test_cg")};
+  se_aply.add_object(se);
+  se_aply.expand_objects(pb_config);
+#endif
+  se_aply.resolve_object(se, err);
 
   int now{50000};
   set_time(now);
@@ -931,13 +959,11 @@ TEST_F(ServiceNotification, WarnCritServiceNotification) {
   ASSERT_EQ(_host->services.size(), 1u);
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
   _svc->set_current_state(engine::service::state_critical);
   _svc->set_last_state(engine::service::state_critical);
   _svc->set_last_hard_state_change(43200);
@@ -968,13 +994,11 @@ TEST_F(ServiceNotification, SimpleNormalVolatileServiceNotification) {
   ASSERT_EQ(_host->services.size(), 1u);
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
   _svc->set_current_state(engine::service::state_critical);
   _svc->set_last_state(engine::service::state_critical);
   _svc->set_last_hard_state_change(43200);
@@ -1003,7 +1027,11 @@ TEST_F(ServiceNotification, SimpleNormalVolatileServiceNotification) {
   id = _svc->get_next_notification_id();
   _svc->set_notification_period_ptr(tperiod.get());
   _svc->set_notifications_enabled(true);
+#ifdef LEGACY_CONF
   config->enable_notifications(false);
+#else
+  pb_config.set_enable_notifications(false);
+#endif
   ASSERT_EQ(_svc->notify(notifier::reason_normal, "", "",
                          notifier::notification_option_none),
             OK);
@@ -1017,13 +1045,11 @@ TEST_F(ServiceNotification, RecoveryNotifEvenIfServiceAcknowledged) {
   ASSERT_EQ(_host->services.size(), 1u);
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
+      new_timeperiod_with_timeranges("tperiod", "alias")};
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0,
-                                    "tperiod", 7, Uuid())};
+                                    "tperiod", 7, 12345)};
   _svc->set_current_state(engine::service::state_critical);
   _svc->set_last_state(engine::service::state_critical);
   _svc->set_last_hard_state_change(43200);
@@ -1072,18 +1098,16 @@ TEST_F(ServiceNotification, RecoveryNotifEvenIfServiceAcknowledged) {
 
 TEST_F(ServiceNotification, SimpleVolatileServiceNotificationWithDowntime) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _svc->set_scheduled_downtime_depth(30);
   _svc->set_is_volatile(true);
   uint64_t id{_svc->get_next_notification_id()};
-  for (int i = 0; i < 7; ++i)
-    tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::serviceescalation> service_escalation{
       new engine::serviceescalation("test_host", "test_svc", 0, 1, 1.0, "", 7,
-                                    Uuid())};
+                                    12345)};
   _svc->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(service_escalation);
