@@ -29,8 +29,8 @@
 #include "com/centreon/engine/configuration/applier/contact.hh"
 #include "com/centreon/engine/configuration/applier/host.hh"
 #include "com/centreon/engine/configuration/applier/service.hh"
-#include "com/centreon/engine/configuration/host.hh"
-#include "com/centreon/engine/configuration/service.hh"
+#include "common/engine_legacy_conf/host.hh"
+#include "common/engine_legacy_conf/service.hh"
 
 #include "opentelemetry/proto/collector/metrics/v1/metrics_service.pb.h"
 #include "opentelemetry/proto/common/v1/common.pb.h"
@@ -361,7 +361,7 @@ static const char* agent_exemple = R"(
 
 class otl_agent_check_result_builder_test : public TestEngine {
  protected:
-  absl::flat_hash_map<std::string /*service name*/, metrics_to_datapoints>
+  absl::flat_hash_map<std::string /*service name*/, metric_to_datapoints>
       _received;
 
  public:
@@ -375,7 +375,7 @@ class otl_agent_check_result_builder_test : public TestEngine {
     otl_data_point::extract_data_points(
         request, [&](const otl_data_point& data_pt) {
           std::string service_name;
-          for (const auto attrib : data_pt.get_resource().attributes()) {
+          for (const auto& attrib : data_pt.get_resource().attributes()) {
             if (attrib.key() == "service.name") {
               service_name = attrib.value().string_value();
               break;
@@ -434,4 +434,4 @@ TEST_F(otl_agent_check_result_builder_test, test_svc_builder_2) {
   };
 
   ASSERT_PRED1(compare_to_excepted, res.get_output());
-}
\ No newline at end of file
+}
